@@ -547,8 +547,8 @@ memset(buff, 0, bufflen);
 p = 0;
 while((lineptr[p] != '*') && (lineptr[p] != 0) && (p /2 <= bufflen))
 	{
-	if(! isxdigit(lineptr[p +0])) return 0;
-	if(! isxdigit(lineptr[p +1])) return 0;
+	if(! isxdigit((unsigned char)lineptr[p +0])) return 0;
+	if(! isxdigit((unsigned char)lineptr[p +1])) return 0;
 	if((lineptr[p +1] == '*') && (lineptr[p +1] == 0)) return 0;
 	idx0 = ((uint8_t)lineptr[p +0] &0x1F) ^0x10;
 	idx1 = ((uint8_t)lineptr[p +1] &0x1F) ^0x10;
@@ -916,7 +916,7 @@ if((statinfo.st_size %HCCAPX_SIZE) != 0)
 	fprintf(stderr, "file corrupt\n");
 	return;
 	}
-if((fhhcx = fopen(hccapxname, "rb")) == NULL)
+if((fhhcx = fopen(hccapxname, "r")) == NULL)
 	{
 	fprintf(stderr, "error opening file %s", hccapxname);
 	return;
@@ -1108,7 +1108,7 @@ if((statinfo.st_size %HCCAP_SIZE) != 0)
 	return;
 	}
 
-if((fhhc = fopen(hccapname, "rb")) == NULL)
+if((fhhc = fopen(hccapname, "r")) == NULL)
 	{
 	fprintf(stderr, "error opening file %s", hccapname);
 	return;
@@ -1537,14 +1537,14 @@ return;
 __attribute__ ((noreturn))
 static void version(char *eigenname)
 {
-printf("%s %s (C) %s ZeroBeat\n", eigenname, VERSION_TAG, VERSION_YEAR);
+fprintf(stdout, "%s %s (C) %s ZeroBeat\n", eigenname, VERSION_TAG, VERSION_YEAR);
 exit(EXIT_SUCCESS);
 }
 /*---------------------------------------------------------------------------*/
 __attribute__ ((noreturn))
 static void usage(char *eigenname)
 {
-printf("%s %s (C) %s ZeroBeat\n"
+fprintf(stdout, "%s %s (C) %s ZeroBeat\n"
 	"usage:\n"
 	"%s <options>\n"
 	"\n"
@@ -1569,7 +1569,7 @@ exit(EXIT_SUCCESS);
 __attribute__ ((noreturn))
 static void usageerror(char *eigenname)
 {
-printf("%s %s (C) %s by ZeroBeat\n"
+fprintf(stdout, "%s %s (C) %s by ZeroBeat\n"
 	"usage: %s -h for help\n", eigenname, VERSION_TAG, VERSION_YEAR, eigenname);
 exit(EXIT_FAILURE);
 }
